@@ -8,7 +8,6 @@ PYTHONIC_NS_BEGIN
 
 namespace operator_
 {
-#if PY_MAJOR_VERSION >= 3
   template <class A, class B>
   auto div(A const &a, B const &b) // for ndarrays
       -> typename std::enable_if<!std::is_fundamental<A>::value ||
@@ -16,12 +15,6 @@ namespace operator_
                                  decltype(a / b)>::type;
 
   double div(double a, double b);
-#else
-  template <class A, class B>
-  auto div(A const &a, B const &b) -> decltype(a / b);
-
-  DEFINE_ALL_OPERATOR_OVERLOADS_DECL(div, / )
-#endif
 
   DEFINE_FUNCTOR(pythonic::operator_, div);
 }
